@@ -153,8 +153,11 @@ INIT {
 	$_eix_cmd = qx{which eix 2>/dev/null};
 	defined($_eix_cmd)
         and chomp $_eix_cmd
+        and length($_eix_cmd)
         and -x $_eix_cmd
-        and $_has_eix = 1;
+        and $_has_eix = 1
+        and debugMsg("Found eix in \"$_eix_cmd\"")
+         or $_has_eix = 0;
 	
 	# Initialize basics
 	_determine_eprefix_portdir;
@@ -211,9 +214,9 @@ INIT {
 sub debugMsg
 {
 	my ($msg) = @_;
-	DEBUG or return;
+	DEBUG or return 1;
 	print STDERR "$msg\n";
-	return;
+	return 1;
 }
 
 # --- private methods implementations ---
@@ -415,7 +418,8 @@ sub _determine_profiles
 	@_profiles = -l $mp_path ? _norm_path('/etc', $mp) : $mp;
 	for (my $i = -1; $i >= -@_profiles; $i--) {
 		for(_noncomments("${_profiles[$i]}/parent")) {
-			splice(@_profiles, $i, 0, _norm_path(${_profiles[$i]}, $_));
+			length($_)
+				and splice(@_profiles, $i, 0, _norm_path(${_profiles[$i]}, $_));
 		}
 	}
 	return;
@@ -427,19 +431,19 @@ sub _determine_profiles
 # No parameters accepted
 sub _final_cleaning
 {
-	# The "disable all" flag is truncated to '*' by the parsing, but it
-	# has to read '-*'.
+	# The "disable all" flag is truncated to '*' by the parsing, but
+	# it has to read '-*'.
 	_add_temp("-*", "global");
 
 	$_use_temp->{'-*'}{global}{descr} = "{Never enable any flags other than those specified in make.conf}";
 	$_use_temp->{'-*'}{global}{conf} = 0; ## Can never be -1
-	
+
 	# Set it from the truncated config:
 	if (defined($_use_temp->{'*'}{global})) {
-		$_use_temp->{'*'}{global}{conf} > 0
+		$_use_temp->{'*'}{global}{conf} > -1
 			and $_use_temp->{'-*'}{global}{conf} = 1;
 	}
-	
+
 	# The following use flags are dangerous or internal only
 	# and must no be available using ufed:
 	defined($_use_temp->{"*"})         and delete($_use_temp->{"*"});
@@ -705,19 +709,28 @@ sub _merge_env {
 }
 
 
-# returns a list of all lines of a given file
+# returns a list of all lines of a given file/dir
 # that are no pure comments
-# Parameter 1: filename
+# Parameter 1: filename/dirname
 sub _noncomments {
 	my ($fname) = @_;
-	my @result;
-	local $/;
-	if(open my $file, '<', $fname) {
-		binmode( $file, ":encoding(UTF-8)" );
-		@result = split /(?:[^\S\n]*(?:#.*)?\n)+/, <$file>."\n";
-		shift @result if @result>0 && $result[0] eq '';
-		close $file;
+	my @result  = ();
+
+	if(-d $fname) {
+		for my $i (_get_files_from_dir($fname)) {
+			(-f $i) && push @result, _noncomments($i);
+		}
+	} else {
+		local $/;
+		if(open my $file, '<', $fname) {
+			binmode( $file, ":encoding(UTF-8)" );
+			my $content = <$file> || "";
+			close $file;
+			@result = split /(?:[^\S\n]*(?:#.*)?\n)+/, "$content\n";
+			shift @result while ( (@result > 0) && !length($result[0]) );
+		}
 	}
+
 	return @result;
 }
 
@@ -755,7 +768,8 @@ sub _read_archs {
 	for my $dir(@_profiles) {
 		next unless (-r "$dir/arch.list");
 		for my $arch (_noncomments("$dir/arch.list")) {
-			defined($_use_temp->{$arch})
+			length($arch)
+				and defined($_use_temp->{$arch})
 				and delete($_use_temp->{$arch});
 		}
 	}
@@ -849,7 +863,9 @@ sub _read_make_conf {
 
 		$oldEnv{USE}{$flag}
 			and $_use_temp->{$flag}{global}{conf} = 1
-			or  $_use_temp->{$flag}{global}{conf} = -1;
+			 or $flag eq '*'
+			and $_use_temp->{$flag}{global}{conf} = 1
+			 or $_use_temp->{$flag}{global}{conf} = -1;
 	}
 	
 	# Add PORTDIR and overlays to @_profiles
